# -*- coding: utf-8 -*-

"""Console script for s2rename."""
import sys
import click

from . import helpers


@click.command()
@click.argument(
    "folder",
    type=click.Path(
        exists=True,
        file_okay=False,
        dir_okay=True,
        writable=True,
        readable=True,
        allow_dash=False,
    ),
)
@click.option(
    "--from",
    "-f",
    "from_",
    type=click.Choice(["sensovation", "scienion"]),
    required=True,
)
@click.option(
    "--to", "-t", type=click.Choice(["sensovation", "scienion"]), required=True
)
@click.option("--digits", "-d", type=click.IntRange(1, 2), default=1)
@click.option("--ext", "-e", default=None)
@click.option("--verbose", "-v", count=True)
def main(folder, from_, to, digits, ext, verbose):
    """Console script for s2rename."""
    try:
        if from_.startswith("sc"):
            regex = helpers.RE_SCIENION
        else:
            regex = helpers.RE_SENSOVATION
        if to.startswith("sc"):
            template = helpers.template_scienion
        else:
            template = helpers.template_sensovation
        file_list = helpers.get_source_list(folder, ext)
        renamables = helpers.parse_source_list(file_list, regex)
        helpers.rename_files(renamables, template, digits)
    except IOError as e:
        click.echo("could not rename files")
        if verbose:
            raise e
        return 1
    return 0


if __name__ == "__main__":
    sys.exit(main())
